/*
* window touch and move event listeners
*/

const callbacks = {
	move: [],
	up: []
};

function onPointerMove(e){
	callbacks.move.forEach(fn => fn(e));
}

function onPointerUp(e){
	callbacks.up.forEach(fn => fn(e));
}

let listenersActive = false;
function toggleListeners(type, length){
	if (length > 0 && !listenersActive){
		listenersActive = true;
		window.addEventListener('mousemove', onPointerMove);
		window.addEventListener('touchmove', onPointerMove);
		window.addEventListener('mouseup', onPointerUp);
		window.addEventListener('touchend', onPointerUp);
	} else if (length == 0 && listenersActive){
		window.removeEventListener('mousemove', onPointerMove);
		window.removeEventListener('touchmove', onPointerMove);
		window.removeEventListener('mouseup', onPointerUp);
		window.removeEventListener('touchend', onPointerUp);
		listenersActive = false;
	}
}

const methods = {
	addListener: (type, fn) => {
		if (callbacks[type].includes(fn)) return;
		else callbacks[type].push(fn);
		toggleListeners(type, callbacks[type].length);
	},
	removeListener: (type, fn) => {
		callbacks[type] = callbacks[type].filter(cb => cb != fn);
		toggleListeners(type, callbacks[type].length);
	}
};

module.exports = methods;
